@@ -1,3 +1,4 @@
+import math
 from typing import Tuple
 
 import numpy as np
@@ -60,10 +61,10 @@ Returns:
     def residuals(xyrv: np.ndarray) -> np.ndarray:
         x, y, r, v = np.split(xyrv, 4)
 
-        x1, x2 = x[0 : N - 1], x[1:N]
-        y1, y2 = y[0 : N - 1], y[1:N]
-        r1, r2 = r[0 : N - 1], r[1:N]
-        v1, v2 = v[0 : N - 1], v[1:N]
+        x1, x2 = x[0:N - 1], x[1:N]
+        y1, y2 = y[0:N - 1], y[1:N]
+        r1, r2 = r[0:N - 1], r[1:N]
+        v1, v2 = v[0:N - 1], v[1:N]
 
         return w * np.hstack(
             [
@@ -125,10 +126,10 @@ def fit_ackerman_model_exact(
     wgv: np.ndarray,
     ws: float = 5.0,
     wa: float = 5.0,
-    min_acc: float = -0.1,
-    max_acc: float = 0.1,
-    min_steer: float = -0.2,
-    max_steer: float = 0.2,
+    min_acc: float = -0.3,  # min acceleration: -3 mps2
+    max_acc: float = 0.3,   # max acceleration: 3 mps2
+    min_steer: float = -math.radians(45) * 0.1,  # max yaw rate: 45 degrees per second
+    max_steer: float = math.radians(45) * 0.1,   # max yaw rate: 45 degrees per second
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
     """
 Fits feasible ackerman-steering trajectory to groundtruth control points.
