@@ -6,9 +6,7 @@ import numpy as np
 
 class Perturbation(ABC):
     @abstractmethod
-    def perturb(
-        self, history_frames: np.ndarray, future_frames: np.ndarray, **kwargs: dict  # Or zarr array  # Or zarr array
-    ) -> Tuple[np.ndarray, np.ndarray]:
+    def perturb(self, history_frames: np.ndarray, future_frames: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
         """
         Args:
             history_frames (np.ndarray): array of past frames
