@@ -13,12 +13,13 @@ class SemBoxRasterizer(Rasterizer):
     """
 
     def __init__(
-        self,
-        render_context: RenderContext,
-        filter_agents_threshold: float,
-        history_num_frames: int,
-        semantic_map_path: str,
-        world_to_ecef: np.ndarray,
+            self,
+            render_context: RenderContext,
+            filter_agents_threshold: float,
+            history_num_frames: int,
+            semantic_map_path: str,
+            world_to_ecef: np.ndarray,
+            render_ego_history: bool = True,
     ):
         super(SemBoxRasterizer, self).__init__()
         self.render_context = render_context
@@ -28,15 +29,15 @@ class SemBoxRasterizer(Rasterizer):
         self.filter_agents_threshold = filter_agents_threshold
         self.history_num_frames = history_num_frames
 
-        self.box_rast = BoxRasterizer(render_context, filter_agents_threshold, history_num_frames)
+        self.box_rast = BoxRasterizer(render_context, filter_agents_threshold, history_num_frames, render_ego_history)
         self.sem_rast = SemanticRasterizer(render_context, semantic_map_path, world_to_ecef)
 
     def rasterize(
-        self,
-        history_frames: np.ndarray,
-        history_agents: List[np.ndarray],
-        history_tl_faces: List[np.ndarray],
-        agent: Optional[np.ndarray] = None,
+            self,
+            history_frames: np.ndarray,
+            history_agents: List[np.ndarray],
+            history_tl_faces: List[np.ndarray],
+            agent: Optional[np.ndarray] = None,
     ) -> np.ndarray:
         im_out_box = self.box_rast.rasterize(history_frames, history_agents, history_tl_faces, agent)
         im_out_sem = self.sem_rast.rasterize(history_frames, history_agents, history_tl_faces, agent)
