@@ -1,13 +1,9 @@
 from .gif import write_gif
-from .utils import (
-    PREDICTED_POINTS_COLOR,
-    REFERENCE_TRAJ_COLOR,
-    TARGET_POINTS_COLOR,
-    draw_reference_trajectory,
-    draw_trajectory,
-)
+from .utils import (draw_reference_trajectory, draw_trajectory, PREDICTED_POINTS_COLOR, REFERENCE_TRAJ_COLOR,
+                    TARGET_POINTS_COLOR)
 from .video import write_video
 
+
 __all__ = [
     "write_gif",
     "write_video",
